==> marble-4.11.2.tar.xz: marble-4.11.2/src/plugins/render/elevationprofilefloatitem/ElevationProfilePlotAxis.h <==
//
// This file is part of the Marble Virtual Globe.
//
// This program is free software licensed under the GNU LGPL. You can
// find a copy of this license in LICENSE.txt in the top directory of
// the source code.
//
// Copyright 2011-2012 Florian Eßer <f.esser@rwth-aachen.de>
//

#ifndef ELEVATIONPROFILEPLOTAXIS_H
#define ELEVATIONPROFILEPLOTAXIS_H

#include <QtCore/QObject>
#include <QList>
#include <QString>

namespace Marble
{

struct AxisTick {
    int position;
    qreal value;
    AxisTick( const int &position_, const qreal &value_ ) :
        position( position_ ),
        value( value_ )
    {
        // nothing to do
    }
};
typedef QList<AxisTick> AxisTickList;

 /**
 * @short A helper class handling a plot axis for the Elevation Profile
 *
 */
class ElevationProfilePlotAxis : public QObject
{
    Q_OBJECT
  private:
    qreal m_minValue;
    qreal m_maxValue;
    qreal m_displayScale;
    int m_pixelLength;
    int m_minTickCount;
    int m_maxTickCount;
    QString m_unitString;
    AxisTickList m_ticks;

    void updateTicks();
    void updateScale();

  public:
    explicit ElevationProfilePlotAxis( );
    void setRange( const qreal &minValue, const qreal &maxValue );
    void setLength( const int &length );
    void setTickCount( const int min, const int max );
    void update();
    qreal minValue() const;
    qreal maxValue() const;
    qreal range() const;
    qreal scale() const;
    QString unit() const;
    AxisTickList ticks() const;
};

}
#endif // ELEVATIONPROFILEPLOTAXIS_H

==> marble-16.12.1.tar.xz: marble-16.12.1/src/plugins/render/elevationprofilefloatitem/ElevationProfilePlotAxis.h <==
//
// This file is part of the Marble Virtual Globe.
//
// This program is free software licensed under the GNU LGPL. You can
// find a copy of this license in LICENSE.txt in the top directory of
// the source code.
//
// Copyright 2011-2012 Florian Eßer <f.esser@rwth-aachen.de>
//

#ifndef ELEVATIONPROFILEPLOTAXIS_H
#define ELEVATIONPROFILEPLOTAXIS_H

#include <QObject>
#include <QVector>
#include <QString>

namespace Marble
{

struct AxisTick {
    int position;
    qreal value;
    AxisTick() :
        position(0),
        value(0.0)
    {
    }
    AxisTick(int position_, qreal value_) :
        position( position_ ),
        value( value_ )
    {
        // nothing to do
    }
};
typedef QVector<AxisTick> AxisTickList;

 /**
 * @short A helper class handling a plot axis for the Elevation Profile
 *
 */
class ElevationProfilePlotAxis : public QObject
{
    Q_OBJECT
  private:
    qreal m_minValue;
    qreal m_maxValue;
    qreal m_displayScale;
    int m_pixelLength;
    int m_minTickCount;
    int m_maxTickCount;
    QString m_unitString;
    AxisTickList m_ticks;

    void updateTicks();
    void updateScale();

  public:
    explicit ElevationProfilePlotAxis( );
    void setRange(qreal minValue, qreal maxValue);
    void setLength(int length);
    void setTickCount( const int min, const int max );
    void update();
    qreal minValue() const;
    qreal maxValue() const;
    qreal range() const;
    qreal scale() const;
    QString unit() const;
    AxisTickList ticks() const;
};

}

Q_DECLARE_TYPEINFO(Marble::AxisTick, Q_PRIMITIVE_TYPE);

#endif // ELEVATIONPROFILEPLOTAXIS_H
